/**
 * @file geis_grail_backend.c
 * @brief GEIS grail client back end
 */

/*
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License version 3, as published 
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranties of 
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "geis_config.h"
#include "geis_grail_backend.h"
#include "geis_backend.h"
#include "geis_backend_protected.h"

#include "geis_event.h"
#include "geis_grail_token.h"
#include "geis_logging.h"
#include "geis_private.h"


/**
 * @addtogroup geis_backend_grail GEIS Grail Back End
 * @ingroup geis_backends
 *
 * A GEIS Back End that wraps a grail instance.
 *
 * @{
 */

/** The less opaque Grail Back End structure. */
struct GeisGrailBackend
{
  Geis            geis;
};


/**
 * Constructs a Grail back end.
 *
 * @param[in] mem
 * @param[in] geis
 */
static void
_geis_grail_backend_construct(void *mem, Geis geis)
{
  GeisGrailBackend gdb = (GeisGrailBackend)mem;
  gdb->geis = geis;
}


/**
 * Deconstructs a Grail back end.
 *
 * @param[in] be  A %GeisGrailBackend.
 */
static void 
_geis_grail_backend_finalize(GeisBackend be)
{
  GeisGrailBackend gdb GEIS_UNUSED = (GeisGrailBackend)be;
}


static struct GeisBackendVtable gdb_vtbl = {
  _geis_grail_backend_construct,
  _geis_grail_backend_finalize,
  geis_grail_token_new
};


/*
 * Activates a GEIS subscription on the back end.
 *
 * @todo replace this stub
 */
GeisStatus
geis_grail_backend_activate_subscription(GeisGrailBackend gbe GEIS_UNUSED,
                                         GeisSubscription subscription GEIS_UNUSED)
{
  GeisStatus status = GEIS_STATUS_UNKNOWN_ERROR;
  return status;
}


/*
 * Deactivates a GEIS subscription on the back end.
 *
 * @todo replace this stub
 */
GeisStatus
geis_grail_backend_deactivate_subscription(GeisGrailBackend gbe GEIS_UNUSED,
                                           GeisSubscription subscription GEIS_UNUSED)
{
  GeisStatus status = GEIS_STATUS_UNKNOWN_ERROR;
  return status;
}


/**
 * Registers the back end with the GEIS back end registry.
 */
static void __attribute__((constructor))
_register_grail_backend(void)
{
  geis_register_backend(GEIS_INIT_UTOUCH_GRAIL_BACKEND,
                        sizeof(struct GeisGrailBackend),
                        &gdb_vtbl);
}


/** A dummy routine to force linkage of this module without dlopening it */
void
geis_include_grail_backend(void)
{
}

/** @} */
